@@ -2,7 +2,7 @@
 #include <iostream>
 #include <stdexcept>
 
-// $Id: example2.cpp,v 1.3 2003/01/24 17:13:51 taku-ku Exp $;
+// $Id: example2.cpp,v 1.4 2003/05/03 10:14:22 taku-ku Exp $;
 // c++ -I/usr/local/include -L/usr/local/lib -o example2 example2.cpp -lmecab
 
 int main (int argc, char **argv)
@@ -16,18 +16,18 @@ int main (int argc, char **argv)
       std::cout << "INPUT:" << std::endl << p << std::endl;
       
       const char *r = t.parse (p);
-      std::cout << "OUTPUT:" << std::endl << (void *) r;
-      const char *r2 = t.parse (p);
-      std::cout << "OUTPUT:" << std::endl << (void *) r2;
+      std::cout << "OUTPUT:" << std::endl << r;
+
+      // t.lock ();
 
-      cout << t.lock () << endl;
       MeCab::Node *n = t.parseToNode(p);
       for (; n; n = n->next) {
 	 std::cout.write (n->surface, n->length);
 	 std::cout << "\t" << n->feature << std::endl;
       }
       std::cout << "EOS\n";
-      t.unlock ();
+
+      // t.unlock ();
 
       return 0;
    } 
