@@ -1,7 +1,7 @@
 /*
  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
 
- $Id: common.h,v 1.16 2003/03/14 05:46:40 taku-ku Exp $;
+ $Id: common.h,v 1.17 2003/07/01 06:43:20 taku-ku Exp $;
 
  Copyright (C) 2001-2002  Taku Kudo <taku-ku@is.aist-nara.ac.jp>
  All rights reserved.
@@ -41,6 +41,8 @@ Copyright (C) 2001-2003 Taku Kudo, All rights reserved.\n"
 #define  TEXT_DIC_FILE        "dic.csv"
 #define  TEXT_CONNECTION_FILE "connect.csv"
 
+#define NBEST_MAX (512)
+
 #define NODE_FREELIST_SIZE (2048)
 #define PATH_FREELIST_SIZE (2048 * 8)
 
@@ -66,6 +68,7 @@ Copyright (C) 2001-2003 Taku Kudo, All rights reserved.\n"
 #include <string>
 #include <stdexcept>
 #include <cstdlib>
+#include <algorithm>
 
 namespace MeCab {
 
@@ -73,7 +76,29 @@ namespace MeCab {
 
   template <class T> inline T _min (T x, T y) { return (x < y) ? x : y; }
   template <class T> inline T _max (T x, T y) { return (x > y) ? x : y; }
-  template <class T> inline void _swap (T &x, T &y) { T z = x; x = y; y = z; }
+
+  static inline void itoa (int val, char *s)
+  {
+     char *t;
+     int mod;
+     if(val < 0) {
+	*s++ = '-';
+	val = -val;
+     }
+     t = s;
+   
+     while(val) {
+	mod = val % 10;
+	*t++ = (char)mod + '0';
+	val /= 10;
+     }
+
+     if (s == t) *t++ = '0';
+     *t = '\0';
+     std::reverse (s, t);
+     
+     return;
+  }
    
   static inline char *mystrdup (const char *str)
   {
