@@ -1,7 +1,7 @@
 /*
  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
 
- $Id: libmecab.cpp,v 1.16 2003/01/03 08:47:33 taku-ku Exp $;
+ $Id: libmecab.cpp,v 1.18 2003/07/01 06:43:21 taku-ku Exp $;
 
  Copyright (C) 2001-2002  Taku Kudo <taku-ku@is.aist-nara.ac.jp>
  All rights reserved.
@@ -30,6 +30,11 @@
 
 static std::string errorStr;
 
+struct _mecab_t {
+   int allocated;
+   void *ptr;
+};
+
 int mecab_do (int argc, char **argv)
 {
   MeCab::Tagger tagger;
@@ -96,7 +101,7 @@ void mecab_destroy (mecab_t *c)
 
 #define MECAB_CHECK_FIRST_ARG(a,c,t) \
  if (! (c) || ! (c)->allocated) { \
-    errorStr = std::string (a) + ": First argment is invalid"; \
+    errorStr = std::string (a) + ": first argment seems to be invalid"; \
     return 0; \
  } \
  MeCab::Tagger *(t) = static_cast<MeCab::Tagger *>((c)->ptr);
@@ -144,4 +149,52 @@ mecab_node_t *mecab_sparse_tonode2 (mecab_t *c, char *str, unsigned int len)
   return reinterpret_cast<mecab_node_t *>(t->parseToNode (str,len));
 }
 
+char* mecab_nbest_sparse_tostr (mecab_t* c, unsigned int N, char*str)
+{
+  MECAB_CHECK_FIRST_ARG("mecab_nbest_sparse_tostr",c,t);
+  return const_cast<char *>(t->parseNBest (N, str));
+}
+
+char* mecab_nbest_sparse_tostr2 (mecab_t* c, unsigned int N, char*str, unsigned int len)
+{
+  MECAB_CHECK_FIRST_ARG("mecab_nbest_sparse_tostr2",c,t);
+  return const_cast<char *>(t->parseNBest (N, str, len));
+}
+
+char* mecab_nbest_sparse_tostr3 (mecab_t* c, unsigned int N, char *str, unsigned int len,
+				 char *out, unsigned int len2)
+{
+  MECAB_CHECK_FIRST_ARG("mecab_nbest_sparse_tostr3",c,t);
+  return const_cast<char *>(t->parseNBest (N, str, len, out, len2));
+}
+
+int mecab_nbest_init (mecab_t *c, char *str)
+{
+  MECAB_CHECK_FIRST_ARG("mecab_nbest_init",c,t);
+  return t->parseNBestInit (str);
+}
+
+int mecab_nbest_init2 (mecab_t *c, char *str, unsigned int len)
+{
+  MECAB_CHECK_FIRST_ARG("mecab_nbest_init2",c,t);
+  return t->parseNBestInit (str, len);
+}
+
+char* mecab_nbest_next_tostr (mecab_t* c)
+{
+  MECAB_CHECK_FIRST_ARG("mecab_nbest_next_tostr",c, t)
+  return const_cast<char *>(t->next ());
+}
+
+char* mecab_nbest_next_tostr2 (mecab_t* c, char *out, unsigned int len2)
+{
+  MECAB_CHECK_FIRST_ARG("mecab_nbest_next_tostr2",c,t);
+  return const_cast<char *>(t->next (out, len2));
+}
+
+mecab_node_t* mecab_nbest_next_tonode (mecab_t* c)
+{
+  MECAB_CHECK_FIRST_ARG("mecab_nbest_next_tonode",c,t);
+  return reinterpret_cast<mecab_node_t *>(t->nextNode ());
+}
 
